Index: channels/chan_skinny.c
===================================================================
--- channels/chan_skinny.c	(revision 249687)
+++ channels/chan_skinny.c	(working copy)
@@ -2411,6 +2411,26 @@
 	transmit_response(d, req);
 }
 
+static void transmit_startmediatransmission(struct skinny_device *d, struct skinny_subchannel *sub, struct sockaddr_in dest, struct ast_format_list fmt)
+{
+	struct skinny_req *req;
+
+	if (!(req = req_alloc(sizeof(struct start_media_transmission_message), START_MEDIA_TRANSMISSION_MESSAGE)))
+		return;
+
+	req->data.startmedia.conferenceId = htolel(sub->callid);
+	req->data.startmedia.passThruPartyId = htolel(sub->callid);
+	req->data.startmedia.remoteIp = dest.sin_addr.s_addr;
+	req->data.startmedia.remotePort = htolel(ntohs(dest.sin_port));
+	req->data.startmedia.packetSize = htolel(fmt.cur_ms);
+	req->data.startmedia.payloadType = htolel(codec_ast2skinny(fmt.bits));
+	req->data.startmedia.qualifier.precedence = htolel(127);
+	req->data.startmedia.qualifier.vad = htolel(0);
+	req->data.startmedia.qualifier.packets = htolel(0);
+	req->data.startmedia.qualifier.bitRate = htolel(0);
+	transmit_response(d, req);
+}
+
 static void transmit_activatecallplane(struct skinny_device *d, struct skinny_line *l)
 {
 	struct skinny_req *req;
@@ -2525,6 +2545,8 @@
 	transmit_response(d, req);
 }
 
+
+
 static int skinny_extensionstate_cb(char *context, char *exten, int state, void *data)
 {
 	struct skinny_speeddial *sd = data;
@@ -2710,11 +2732,9 @@
 	struct skinny_subchannel *sub;
 	struct skinny_line *l;
 	struct skinny_device *d;
-	struct skinnysession *s;
 	struct ast_format_list fmt;
 	struct sockaddr_in us = { 0, };
 	struct sockaddr_in them = { 0, };
-	struct skinny_req *req;
 	
 	sub = c->tech_pvt;
 
@@ -2727,47 +2747,27 @@
 
 	l = sub->parent;
 	d = l->device;
-	s = d->session;
 
 	if (rtp){
 		ast_rtp_instance_get_remote_address(rtp, &them);
 
 		/* Shutdown any early-media or previous media on re-invite */
-		if (!(req = req_alloc(sizeof(struct stop_media_transmission_message), STOP_MEDIA_TRANSMISSION_MESSAGE)))
-			return -1;
-
-		req->data.stopmedia.conferenceId = htolel(sub->callid);
-		req->data.stopmedia.passThruPartyId = htolel(sub->callid);
-		transmit_response(d, req);
-
+		transmit_stopmediatransmission(d, sub);
+		
 		if (skinnydebug)
 			ast_verb(1, "Peerip = %s:%d\n", ast_inet_ntoa(them.sin_addr), ntohs(them.sin_port));
 
-		if (!(req = req_alloc(sizeof(struct start_media_transmission_message), START_MEDIA_TRANSMISSION_MESSAGE)))
-			return -1;
-
 		fmt = ast_codec_pref_getsize(&l->prefs, ast_best_codec(l->capability));
 
 		if (skinnydebug)
 			ast_verb(1, "Setting payloadType to '%s' (%d ms)\n", ast_getformatname(fmt.bits), fmt.cur_ms);
 
-		req->data.startmedia.conferenceId = htolel(sub->callid);
-		req->data.startmedia.passThruPartyId = htolel(sub->callid);
 		if (!(l->directmedia) || (l->nat)){
 			ast_rtp_instance_get_local_address(rtp, &us);
-			req->data.startmedia.remoteIp = d->ourip.s_addr;
-			req->data.startmedia.remotePort = htolel(ntohs(us.sin_port));
+			transmit_startmediatransmission(d, sub, us, fmt);
 		} else {
-			req->data.startmedia.remoteIp = them.sin_addr.s_addr;
-			req->data.startmedia.remotePort = htolel(ntohs(them.sin_port));
+			transmit_startmediatransmission(d, sub, them, fmt);
 		}
-		req->data.startmedia.packetSize = htolel(fmt.cur_ms);
-		req->data.startmedia.payloadType = htolel(codec_ast2skinny(fmt.bits));
-		req->data.startmedia.qualifier.precedence = htolel(127);
-		req->data.startmedia.qualifier.vad = htolel(0);
-		req->data.startmedia.qualifier.packets = htolel(0);
-		req->data.startmedia.qualifier.bitRate = htolel(0);
-		transmit_response(d, req);
 
 		return 0;
 	}
